import { animate, stagger } from "motion";

const links = document.querySelectorAll(".motion-links");
const logo = document.querySelectorAll(".motion-logo");
const text = document.querySelectorAll(".motion-text");
const footer = document.querySelectorAll(".motion-footer");

const elements = [...text, ...logo, ...links, ...footer];

animate(
  elements,
  { opacity: [0, 1] },
  {
    delay: stagger(0.2, { startDelay: 0.1 }),
    ease: "easeIn",
  },
);

document.addEventListener("keydown", ({ key }: KeyboardEvent) => {
  const shortcuts: Record<string, string> = {
    g: "a.git",
    b: "a.blog",
    m: "a.matrix",
  };

  const selector = shortcuts[key.toLowerCase()];
  if (!selector) return;

  const link = document.querySelector(selector) as HTMLAnchorElement | null;
  if (!link?.href) return;

  const a = Object.assign(document.createElement("a"), {
    href: link.href,
    target: link.target,
    rel: link.rel,
    style: "display: none",
  });

  document.body.append(a);
  a.click();
  a.remove();
});
